/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.dao.impl;

import java.util.List;
import javax.persistence.TypedQuery;
import org.apache.syncope.core.persistence.beans.SecurityQuestion;
import org.apache.syncope.core.persistence.beans.user.SyncopeUser;
import org.apache.syncope.core.persistence.dao.SecurityQuestionDAO;
import org.apache.syncope.core.persistence.dao.UserDAO;
import org.apache.syncope.core.persistence.validation.entity.InvalidEntityException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;

@Repository
public class SecurityQuestionDAOImpl extends AbstractDAOImpl implements SecurityQuestionDAO {

    @Autowired
    private UserDAO userDAO;

    @Override
    public SecurityQuestion find(final Long id) {
        return entityManager.find(SecurityQuestion.class, id);
    }

    @Override
    public List<SecurityQuestion> findAll() {
        final TypedQuery<SecurityQuestion> query = entityManager.createQuery(
                "SELECT e FROM " + SecurityQuestion.class.getSimpleName() + " e ", SecurityQuestion.class);
        return query.getResultList();
    }

    @Override
    public SecurityQuestion save(final SecurityQuestion securityQuestion) throws InvalidEntityException {
        return entityManager.merge(securityQuestion);
    }

    @Override
    public void delete(final Long id) {
        SecurityQuestion securityQuestion = find(id);
        if (securityQuestion == null) {
            return;
        }

        for (SyncopeUser user : userDAO.findBySecurityQuestion(securityQuestion)) {
            user.setSecurityQuestion(null);
            user.setSecurityAnswer(null);
            userDAO.save(user);
        }

        entityManager.remove(securityQuestion);
    }

}
